==> openshift-model-hive-5.12.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterStateBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterStateBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterStateFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterStateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterState,io.fabric8.openshift.api.model.hive.v1.ClusterStateBuilder>{
  public ClusterStateBuilder() {
    this(false);
  }
  public ClusterStateBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterState(), validationEnabled);
  }
  public ClusterStateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterStateFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterStateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterStateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterState(), validationEnabled);
  }
  public ClusterStateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterStateFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterState instance) {
    this(fluent, instance, false);
  }
  public ClusterStateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterStateFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterState instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterStateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterState instance) {
    this(instance,false);
  }
  public ClusterStateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterState instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterStateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterState build() {
    ClusterState buildable = new ClusterState(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterStateBuilder that = (ClusterStateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterStateBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterStateBuilder extends ClusterStateFluentImpl<ClusterStateBuilder> implements VisitableBuilder<ClusterState,ClusterStateBuilder>{
  public ClusterStateBuilder() {
    this(false);
  }
  public ClusterStateBuilder(Boolean validationEnabled) {
    this(new ClusterState(), validationEnabled);
  }
  public ClusterStateBuilder(ClusterStateFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterStateBuilder(ClusterStateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterState(), validationEnabled);
  }
  public ClusterStateBuilder(ClusterStateFluent<?> fluent,ClusterState instance) {
    this(fluent, instance, false);
  }
  public ClusterStateBuilder(ClusterStateFluent<?> fluent,ClusterState instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterStateBuilder(ClusterState instance) {
    this(instance,false);
  }
  public ClusterStateBuilder(ClusterState instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterStateFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterState build() {
    ClusterState buildable = new ClusterState(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
